Merge "Add TelephonyManager.getCurrentPhoneType" into honeycomb
diff --git a/core/java/android/accounts/AccountManagerService.java b/core/java/android/accounts/AccountManagerService.java
index fb16609..2e70a56 100644
--- a/core/java/android/accounts/AccountManagerService.java
+++ b/core/java/android/accounts/AccountManagerService.java
@@ -1781,7 +1781,7 @@
             // will return a different value, but we *don't* erase the
             // passwords.  We only erase them if it has a different
             // subscriber ID once it's provisioned.
-            if (telephonyManager.getPhoneType() == TelephonyManager.PHONE_TYPE_CDMA) {
+            if (telephonyManager.getCurrentPhoneType() == TelephonyManager.PHONE_TYPE_CDMA) {
                 IBinder service = ServiceManager.checkService(Context.TELEPHONY_SERVICE);
                 if (service == null) {
                     Log.w(TAG, "call to checkService(TELEPHONY_SERVICE) failed");
diff --git a/telephony/java/android/telephony/TelephonyManager.java b/telephony/java/android/telephony/TelephonyManager.java
index 01f2bae..b0f0a43 100644
--- a/telephony/java/android/telephony/TelephonyManager.java
+++ b/telephony/java/android/telephony/TelephonyManager.java
@@ -276,19 +276,18 @@
     public static final int PHONE_TYPE_SIP = Phone.PHONE_TYPE_SIP;
 
     /**
-     * Returns a constant indicating the device phone type.  This
-     * indicates the type of radio used to transmit voice calls.
+     * Returns the current phone type.
+     * TODO: This is a last minute change and hence hidden.
      *
      * @see #PHONE_TYPE_NONE
      * @see #PHONE_TYPE_GSM
      * @see #PHONE_TYPE_CDMA
      * @see #PHONE_TYPE_SIP
+     *
+     * {@hide}
      */
-    public int getPhoneType() {
+    public int getCurrentPhoneType() {
         try{
-            if (!isVoiceCapable()) {
-                return PHONE_TYPE_NONE;
-            }
             ITelephony telephony = getITelephony();
             if (telephony != null) {
                 return telephony.getActivePhoneType();
@@ -307,6 +306,21 @@
         }
     }
 
+    /**
+     * Returns a constant indicating the device phone type.  This
+     * indicates the type of radio used to transmit voice calls.
+     *
+     * @see #PHONE_TYPE_NONE
+     * @see #PHONE_TYPE_GSM
+     * @see #PHONE_TYPE_CDMA
+     * @see #PHONE_TYPE_SIP
+     */
+    public int getPhoneType() {
+        if (!isVoiceCapable()) {
+            return PHONE_TYPE_NONE;
+        }
+        return getCurrentPhoneType();
+    }
 
     private int getPhoneTypeFromProperty() {
         int type =
diff --git a/telephony/java/android/telephony/CellLocation.java b/telephony/java/android/telephony/CellLocation.java
index 2edfc23..5eaa5a0 100644
--- a/telephony/java/android/telephony/CellLocation.java
+++ b/telephony/java/android/telephony/CellLocation.java
@@ -61,9 +61,9 @@
      * @hide
      */
     public static CellLocation newFromBundle(Bundle bundle) {
         // TelephonyManager.getDefault().getPhoneType() handles the case when
         // ITelephony interface is not up yet.
-        switch(TelephonyManager.getDefault().getPhoneType()) {
+        switch(TelephonyManager.getDefault().getCurrentPhoneType()) {
         case Phone.PHONE_TYPE_CDMA:
             return new CdmaCellLocation(bundle);
         case Phone.PHONE_TYPE_GSM:
@@ -89,9 +89,9 @@
      *
      */
     public static CellLocation getEmpty() {
         // TelephonyManager.getDefault().getPhoneType() handles the case when
         // ITelephony interface is not up yet.
-        switch(TelephonyManager.getDefault().getPhoneType()) {
+        switch(TelephonyManager.getDefault().getCurrentPhoneType()) {
         case Phone.PHONE_TYPE_CDMA:
             return new CdmaCellLocation();
         case Phone.PHONE_TYPE_GSM:
@@ -61,9 +61,9 @@
      */
     public static CellLocation newFromBundle(Bundle bundle) {
-        // TelephonyManager.getDefault().getPhoneType() handles the case when
+        // TelephonyManager.getDefault().getCurrentPhoneType() handles the case when
         // ITelephony interface is not up yet.
@@ -89,9 +89,9 @@
      */
     public static CellLocation getEmpty() {
-        // TelephonyManager.getDefault().getPhoneType() handles the case when
+        // TelephonyManager.getDefault().getCurrentPhoneType() handles the case when
         // ITelephony interface is not up yet.